@@ -12,12 +12,13 @@ use List::Util qw(sum shuffle);
 use File::Spec;
 use File::ShareDir qw(:ALL);
 use File::Find::Rule;
+use Encode;
 use GD;
 use GD::Text::Align;
 use Color::Scheme;
 use Math::PlanePath::TheodorusSpiral;
 
-our $VERSION = '0.02_04';
+our $VERSION = '0.02_05';
 
 $ENV{IWC_DEBUG} = 0 if ! defined $ENV{IWC_DEBUG} || ! $ENV{IWC_DEBUG};
 
@@ -244,8 +245,9 @@ sub words {
   if (scalar(@_) > 1) {
   	my @words = @_;
   	
-		# Strip non-word characters, lc() each word and build the counts
-		foreach my $word (map { lc } @words) {
+  	# Strip non-word characters, lc() each word and build the counts
+  	foreach my $word (map { lc } @words) {
+  		$word = Encode::decode('iso-8859-1', $word);
 			$word =~ s/\W//o;
 			$words{ $word }++;
 		}
@@ -261,6 +263,7 @@ sub words {
 			
 			# Strip non-word characters, lc() each word and build the counts
 			foreach my $word (map { lc } @words) {
+				$word = Encode::decode('iso-8859-1', $word);
 				$word =~ s/\W//o;
 				$words{ $word }++;
 			}
@@ -268,7 +271,9 @@ sub words {
 		# Argument is a scalar, assume it's a string of words
 		else {
 			my $words = $arg1;
-			while ($words =~ /(?<!<)\b([\w\-']+)\b(?!>)/go) { #' <-- so UltraEdit doesnt fubar syntax highliting
+			$words = Encode::decode('iso-8859-1', $words);
+			
+			while ($words =~ /(?<!<)\b([\w\-']+)\b(?!>)/g) { #' <-- so UltraEdit doesnt fubar syntax highliting
 				my $word = lc($1);
 				$word =~ s/\W//o;
 				$words{ $word }++;
